@@ -1,8 +1,8 @@
 import os
 import unittest
 
-from yajwt.jwt_keys_manager import JwtKeysManager
 from yajwt.jwt_requests_validator import JwtRequestsValidator
+from yajwt.keys_manager.jwt_keys_directory_manager import JwtKeysDirectoryManager
 
 
 class TestJwtRequestsValidator(unittest.TestCase):
@@ -22,9 +22,17 @@ class TestJwtRequestsValidator(unittest.TestCase):
 
     def setUp(self) -> None:
         keys_path = os.path.join(os.getcwd(), "examples", "keys")
-        jwt_keys_manager = JwtKeysManager(keys_path)
+        jwt_keys_manager = JwtKeysDirectoryManager(keys_path)
         self.jwt_validator = JwtRequestsValidator(jwt_keys_manager)
 
     def test_validate_expired_token(self):
         jwt_token = self.jwt_validator.validate(self.EXPIRED_TOKEN)
         self.assertEqual(jwt_token.valid, False)
+
+    def test_validate_specific_user_expired_token(self):
+        jwt_token = self.jwt_validator.validate_user("testing-user", self.EXPIRED_TOKEN)
+        self.assertEqual(jwt_token.valid, False)
+
+    def test_validate_invalid_user_expired_token(self):
+        jwt_token = self.jwt_validator.validate_user("ko-user", self.EXPIRED_TOKEN)
+        self.assertEqual(jwt_token.valid, False)
